@@ -1,6 +1,7 @@
 import time
 
 import bytewax
+from bytewax import Dataflow, parse, run_cluster
 
 
 def slow(x):
@@ -25,14 +26,16 @@ def output(x):
     return x.replace("in", "out")
 
 
-ec = bytewax.Executor()
-flow = ec.Dataflow(enumerate(["in1", "in2", "in3", "in4", "in5"]))
+flow = Dataflow()
 flow.inspect(print)
 # flow.map(slow)
 flow.map(busy)
 flow.map(output)
-flow.inspect(print)
+flow.capture()
 
 
 if __name__ == "__main__":
-    ec.build_and_run()
+    for epoch, item in run_cluster(
+        flow, enumerate(["in1", "in2", "in3", "in4", "in5"]), **parse.cluster_args()
+    ):
+        print(epoch, item)
