@@ -1,8 +1,7 @@
 import collections
 import operator
 
-import bytewax
-from bytewax import inp
+from bytewax import Dataflow, inputs, parse, run_cluster
 
 
 # You can define your own functions which add groupings of steps to a
@@ -26,8 +25,7 @@ def inspector(count_count):
     )
 
 
-ec = bytewax.Executor()
-flow = ec.Dataflow(inp.single_batch(open("examples/sample_data/wordcount.txt")))
+flow = Dataflow()
 # "at this point we have full sentences as items in the dataflow"
 flow.flat_map(str.split)
 # "words"
@@ -37,8 +35,13 @@ flow.map(get_count)
 # count
 calc_counts(flow)
 # (that_same_count, num_words_with_the_same_count)
-flow.inspect(inspector)
+flow.capture()
 
 
 if __name__ == "__main__":
-    ec.build_and_run()
+    for epoch, item in run_cluster(
+        flow,
+        inputs.single_batch(open("examples/sample_data/wordcount.txt")),
+        **parse.cluster_args(),
+    ):
+        inspector(item)
