@@ -1,10 +1,9 @@
 import json
 import operator
-import time
+from datetime import timedelta
 from collections import defaultdict
 
-import bytewax
-from bytewax import inp
+from bytewax import Dataflow, inputs, parse, run_cluster
 
 from utils import twitter
 
@@ -25,8 +24,7 @@ def initial_count(coin):
     return coin, 1
 
 
-ec = bytewax.Executor()
-flow = ec.Dataflow(inp.tumbling_epoch(2.0, twitter.get_stream()))
+flow = Dataflow()
 # "event_json"
 flow.flat_map(decode)
 # {event_dict}
@@ -36,8 +34,11 @@ flow.map(initial_count)
 # ("coin", 1)
 flow.reduce_epoch(operator.add)
 # ("coin", count)
-flow.inspect(print)
+flow.capture()
 
 
 if __name__ == "__main__":
-    ec.build_and_run()
+    for epoch, item in run_cluster(
+        flow, inputs.tumbling_epoch(twitter.get_stream(), timedelta(seconds=2)), **parse.cluster_args()
+    ):
+        print(epoch, item)
