@@ -1,7 +1,6 @@
 import re
 
-import bytewax
-from bytewax import inp
+from bytewax import Dataflow, parse, run_cluster
 
 
 def file_input():
@@ -25,8 +24,7 @@ def add(count1, count2):
     return count1 + count2
 
 
-ec = bytewax.Executor()
-flow = ec.Dataflow(file_input())
+flow = Dataflow()
 # "Here, we have FULL sentences."
 flow.map(lower)
 # "here, we have lowercase sentences."
@@ -36,8 +34,9 @@ flow.map(initial_count)
 # ("word", 1)
 flow.reduce_epoch(add)
 # ("word", count)
-flow.inspect_epoch(print)
+flow.capture()
 
 
 if __name__ == "__main__":
-    ec.build_and_run()
+    for epoch, item in run_cluster(flow, file_input(), **parse.cluster_args()):
+        print(epoch, item)
